==> 0.1.3.tar.gz: ios/Classes/types/hub/FlutterOutboxMutationEnqueuedEvent.swift <==
/*
 * Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

import Foundation
import Amplify
import AmplifyPlugins

struct FlutterOutboxMutationEnqueuedEvent: FlutterHubEvent {
    var eventName: String
    var modelName: String
    var element:  FlutterHubElement
    
    init(outboxMutationEnqueued: OutboxMutationEvent, eventName: String, schema: ModelSchema?) throws {
        self.eventName = shortEventName(eventName: eventName)
        self.modelName = outboxMutationEnqueued.modelName
        do {
            if (schema != nil) {
                self.element = try FlutterHubElement(hubElement: outboxMutationEnqueued.element, schema: schema!)
            } else {
                throw FlutterDataStoreError.acquireSchemaForHub
            }
        } catch {
            throw error
        }
        
    }
    
    func toValueMap() -> Dictionary<String, Any> {
        return [
            "eventName": self.eventName,
            "modelName": self.modelName,
            "element": self.element.toValueMap() as Any
        ]
    }
}

==> 0.2.6.tar.gz: ios/Classes/types/hub/FlutterOutboxMutationEnqueuedEvent.swift <==
/*
 * Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

import Foundation
import Amplify
import AmplifyPlugins

struct FlutterOutboxMutationEnqueuedEvent: FlutterHubEvent {
    var eventName: String
    var modelName: String
    var element:  FlutterHubElement
    
    init(outboxMutationEnqueued: OutboxMutationEvent, eventName: String, flutterModelRegistration: FlutterModels) throws {
        self.eventName = shortEventName(eventName: eventName)
        self.modelName = outboxMutationEnqueued.modelName
        do {
            self.element = try FlutterHubElement(hubElement: outboxMutationEnqueued.element, flutterModelRegistration: flutterModelRegistration, modelName: self.modelName)
        } catch {
            throw FlutterDataStoreError.acquireSchemaForHub
        }
        
    }
    
    func toValueMap() -> Dictionary<String, Any> {
        return [
            "eventName": self.eventName,
            "modelName": self.modelName,
            "element": self.element.toValueMap() as Any
        ]
    }
}
